//# sourceURL=J_SmartSwitch1.js

var SMART_SWITCH_SID = 'urn:hugheaves-com:serviceId:SmartSwitch1';
var SMART_SWITCH_CONTROLLER_SID = 'urn:hugheaves-com:serviceId:SmartSwitchController1';
var SECURITY_SENSOR_SID = 'urn:micasaverde-com:serviceId:SecuritySensor1';
var SWITCH_SID = 'urn:upnp-org:serviceId:SwitchPower1';

var ss_settingSid;
var ss_settingVar;
var ss_deviceId = 0;
var ss_livedeviceIds;

function ss_showSettings(deviceId) {
	var panelHtml = '';

	ss_deviceId = deviceId;
	ss_settingSid = SMART_SWITCH_SID;
	ss_settingVar = 'SwitchIds';
	
	panelHtml += '<p>To control switches using this plug-in, you must '
			+ 'first add the switches to the list below. '
			+ 'When you save your settings, the plug-in will then '
			+ 'create a new "smart switch" device for each switch in the '
			+ 'list. After the new smart switches have been created, '
			+ 'go to the settings page for each '
			+ 'smart switch to add the sensors that control '
			+ 'that switch.</p>';

	panelHtml += '<p>To add a switch, select a device from the drop-down '
			+ 'below and and click the "Add" button. To remove an existing '
			+ 'switch, click the "Remove" button next to the device. ';

	panelHtml += 'To save your changes (and allow the plug-in to create '
			+ 'or remove the smart switches), remember to click the "Reload Luup" button '
			+ 'at the bottom of the screen after adding or removing devices.</p>';

	panelHtml += ss_deviceSelectDropdown(SWITCH_SID, SWITCH_SID);

	panelHtml += ss_devicesTable();

    //Reload luup button
	panelHtml += '<p><input type="button" value="Reload Luup" onclick="ssc_reload_luup()" /></p>';

	set_panel_html(panelHtml);
}

/*
 * Generic (Shared) functions
 */

function ss_findDevices(sid1, sid2) {
	var foundDevices = [];

	var devices = jsonp.ud.devices;

	for ( var i = 0; i < devices.length; i++) {
		var device = devices[i];
		var found = false;

		for ( var j = 0; j < device.states.length; j++) {
			var state = device.states[j];
			if (state.service == sid1 || state.service == sid2) {
				found = true;
			}
		}

		if (found) {
			foundDevices.push(device);
		}

	}
	return foundDevices;
}

function ss_removeUsedDevices(devices) {
	var deviceIds = ss_getDeviceIdsSetting();
	var newDevices = [];
	
	for ( var i = 0; i < devices.length; ++i) {
		var device = devices[i];
		var index = deviceIds.indexOf(device.id);
		if (index == -1) {
			newDevices.push(device);
		}
	}
	
	return newDevices;
}

function ss_getDeviceIdsSetting() {
	//TIAAN was here
	//Adapted this function to use a temp global variable to show live version of device list
	//otherwise you cannot see added device immediately
	if (ss_livedeviceIds != null) {
		return ss_livedeviceIds;
	}
	//var deviceIdsJSON = get_device_state(ss_deviceId, ss_settingSid, ss_settingVar, 0);
	var deviceIdsJSON = api.getDeviceStateVariable( ss_deviceId, ss_settingSid, ss_settingVar, { dynamic: false } ) || "";

	deviceIdsJSON = deviceIdsJSON.replace(/'/g, '\"');

	if (deviceIdsJSON == "") {
		return ([]);
	} else {
		ss_livedeviceIds = JSON.parse(deviceIdsJSON);
		return (JSON.parse(deviceIdsJSON));
	}
}

function ss_setDeviceIdsSetting(deviceIds) {
	var deviceIdsJSON = JSON.stringify(deviceIds);

	deviceIdsJSON = deviceIdsJSON.replace(/"/g, '\'');

	set_device_state(ss_deviceId, ss_settingSid, ss_settingVar, deviceIdsJSON, 0);
}

function ss_deviceSelectDropdown(sid1, sid2) {
	var panelHtml = '';

	var devices = ss_findDevices(sid1, sid2);
	devices = ss_removeUsedDevices(devices);

	panelHtml += '<select id="deviceSelect">'
	panelHtml += '<option value="0">-- Select a device --</option>'
	for ( var i = 0; i < devices.length; ++i) {
		var device = devices[i];
		panelHtml += '<option value="' + device.id + '">' + device.name + ' (#'
				+ device.id + ')</option>';

	}
	panelHtml += '</select>';
	panelHtml += '<input type="button" value="Add" onclick="ss_addSelectedDevice()" />';
	panelHtml += '<p/>';

	return panelHtml;
}

function ss_get_device_by_id(DeviceID) {
//Wrote this function because the jsonp version does not work for some reason.
	var devices = ss_findDevices(SWITCH_SID, SWITCH_SID);
	
	for ( var i = 0; i < devices.length; ++i) {
		if (devices[i].id == DeviceID){
			return devices[i];
		}
		
	}

	return device;
}

function ss_get_room_by_id(RoomID) {
//Wrote this function because the jsonp version does not work for some reason.
	var rooms = jsonp.ud.rooms;
	
	for ( var i = 0; i < rooms.length; ++i) {
		if (rooms[i].id == RoomID){
			return rooms[i];
		}
		
	}

	return room;
}

function ss_devicesTable() {
	var panelHtml = '';

	panelHtml += ss_tableHeader();
	
	var deviceIds = ss_getDeviceIdsSetting();

	for ( var i = 0; i < deviceIds.length; ++i) {
		device = ss_get_device_by_id(deviceIds[i]);
		panelHtml += ss_tableRow(device);
	}

	panelHtml += ss_tableFooter();

	return panelHtml;
}

function ss_tableHeader() {
	var panelHtml = '';

	panelHtml += '<table style="border-collapse:collapse">';
	panelHtml += '<tr>';
	panelHtml += '<th style="width: 20%">Device Id</th>';
	panelHtml += '<th style="width: 20%">Room</th>';
	panelHtml += '<th style="width: 50%">Name</th>';
	panelHtml += '<th style="width: 20%">Action</th>';
	panelHtml += '</tr>';

	return panelHtml;
}

function ss_tableRow(device) {
	var panelHtml = '';
	var roomName = 'none';

	if (device.room > 0) {
		//roomName = jsonp.get_room_by_id(device.room).name;
		roomName = ss_get_room_by_id(device.room).name;
	}

	panelHtml += '<tr style="border: 1px solid black">';
	panelHtml += '<td style="border: 1px solid black">' + device.id + '</td>';
	panelHtml += '<td style="border: 1px solid black">' + roomName + '</td>';
	panelHtml += '<td style="border: 1px solid black">' + device.name + '</td>';
	panelHtml += '<td style="border: 1px solid black"><input type="button" value="Remove" '
			+ 'onclick="ss_removeDevice(\'' + device.id + '\')" /></td>';
	panelHtml += '</tr>';

	return panelHtml;
}

function ss_tableFooter() {
	return '</table>';
}

function ss_removeDevice(deviceId) {
	var deviceIds = ss_getDeviceIdsSetting();
	var index = deviceIds.indexOf(deviceId);
	if (index > -1) {
		deviceIds.splice(index, 1);
		ss_setDeviceIdsSetting(deviceIds);
		ss_showSettings(ss_deviceId);
	}
}

function ss_addSelectedDevice() {
	var element = document.getElementById("deviceSelect");
	var deviceId = element.options[element.selectedIndex].value;
	var deviceIds = ss_getDeviceIdsSetting();
	var index = deviceIds.indexOf(deviceId);
	if (index == -1 && deviceId > 0) {
		deviceIds.push(deviceId);
		ss_setDeviceIdsSetting(deviceIds);
		ss_showSettings(ss_deviceId);
	}
}

function ssc_reload_luup() {
	application.luReload(); //I think this will cause UI7 to reload on it own!!
}

/**
 * Plugin
 */
var SmartSwitch = ( function( api, $ ) {
	var UUID = "8e5b4558-9620-4beb-bdbb-bea8fe5e08ae";
	var SMART_SWITCH = "urn:hugheaves-com:serviceId:SmartSwitch1";

	myModule = {
		uuid: UUID,

		drawDevice: function( device ) {
			var version = MultiBox.getStatus( device, SMART_SWITCH, "PluginVersion" );
			return '<div class="panel-content">'
				+		'<div class="btn-group" role="group" aria-label="...">'
				+			'v' + version
				+		'</div>'
				+	'</div>';
		}
	};

	return myModule;
})( api, jQuery );
